@@ -244,8 +244,7 @@ virDomainCapsEnumSet(virDomainCapsEnum *capsEnum,
         if (!val) {
             /* Integer overflow */
             virReportError(VIR_ERR_INTERNAL_ERROR,
-                           _("integer overflow on %s. Please contact the "
-                             "libvirt development team at libvir-list@redhat.com"),
+                           _("integer overflow on %1$s. Please contact the libvirt development team at libvir-list@redhat.com"),
                            capsEnumName);
             return -1;
         }
