@@ -27,16 +27,13 @@
 #include "virfile.h"
 #include "virerror.h"
 #include "virlog.h"
-#include "virstring.h"
-#include "virsystemd.h"
-#include "virutil.h"
 
 #define VIR_FROM_THIS VIR_FROM_LXC
 
 VIR_LOG_INIT("lxc.lxc_cgroup");
 
-static int virLXCCgroupSetupCpuTune(virDomainDefPtr def,
-                                    virCgroupPtr cgroup)
+static int virLXCCgroupSetupCpuTune(virDomainDef *def,
+                                    virCgroup *cgroup)
 {
     if (def->cputune.sharesSpecified) {
         if (virCgroupSetCpuShares(cgroup, def->cputune.shares) < 0)
@@ -48,9 +45,9 @@ static int virLXCCgroupSetupCpuTune(virDomainDefPtr def,
 }
 
 
-static int virLXCCgroupSetupCpusetTune(virDomainDefPtr def,
-                                       virCgroupPtr cgroup,
-                                       virBitmapPtr nodemask)
+static int virLXCCgroupSetupCpusetTune(virDomainDef *def,
+                                       virCgroup *cgroup,
+                                       virBitmap *nodemask)
 {
     g_autofree char *mask = NULL;
     virDomainNumatuneMemMode mode;
@@ -77,15 +74,15 @@ static int virLXCCgroupSetupCpusetTune(virDomainDefPtr def,
 }
 
 
-static int virLXCCgroupSetupBlkioTune(virDomainDefPtr def,
-                                      virCgroupPtr cgroup)
+static int virLXCCgroupSetupBlkioTune(virDomainDef *def,
+                                      virCgroup *cgroup)
 {
     return virDomainCgroupSetupBlkio(cgroup, def->blkio);
 }
 
 
-static int virLXCCgroupSetupMemTune(virDomainDefPtr def,
-                                    virCgroupPtr cgroup)
+static int virLXCCgroupSetupMemTune(virDomainDef *def,
+                                    virCgroup *cgroup)
 {
     if (virCgroupSetMemory(cgroup, virDomainDefGetMemoryInitial(def)) < 0)
         return -1;
@@ -94,22 +91,22 @@ static int virLXCCgroupSetupMemTune(virDomainDefPtr def,
 }
 
 
-static int virLXCCgroupGetMemSwapUsage(virCgroupPtr cgroup,
-                                       virLXCMeminfoPtr meminfo)
+static int virLXCCgroupGetMemSwapUsage(virCgroup *cgroup,
+                                       struct virLXCMeminfo *meminfo)
 {
     return virCgroupGetMemSwapUsage(cgroup, &meminfo->swapusage);
 }
 
 
-static int virLXCCgroupGetMemSwapTotal(virCgroupPtr cgroup,
-                                       virLXCMeminfoPtr meminfo)
+static int virLXCCgroupGetMemSwapTotal(virCgroup *cgroup,
+                                       struct virLXCMeminfo *meminfo)
 {
     return virCgroupGetMemSwapHardLimit(cgroup, &meminfo->swaptotal);
 }
 
 
-static int virLXCCgroupGetMemUsage(virCgroupPtr cgroup,
-                                   virLXCMeminfoPtr meminfo)
+static int virLXCCgroupGetMemUsage(virCgroup *cgroup,
+                                   struct virLXCMeminfo *meminfo)
 {
     int ret;
     unsigned long memUsage;
@@ -121,15 +118,15 @@ static int virLXCCgroupGetMemUsage(virCgroupPtr cgroup,
 }
 
 
-static int virLXCCgroupGetMemTotal(virCgroupPtr cgroup,
-                                   virLXCMeminfoPtr meminfo)
+static int virLXCCgroupGetMemTotal(virCgroup *cgroup,
+                                   struct virLXCMeminfo *meminfo)
 {
     return virCgroupGetMemoryHardLimit(cgroup, &meminfo->memtotal);
 }
 
 
-static int virLXCCgroupGetMemStat(virCgroupPtr cgroup,
-                                  virLXCMeminfoPtr meminfo)
+static int virLXCCgroupGetMemStat(virCgroup *cgroup,
+                                  struct virLXCMeminfo *meminfo)
 {
     return virCgroupGetMemoryStat(cgroup,
                                   &meminfo->cached,
@@ -141,7 +138,7 @@ static int virLXCCgroupGetMemStat(virCgroupPtr cgroup,
 }
 
 
-int virLXCCgroupGetMeminfo(virLXCMeminfoPtr meminfo)
+int virLXCCgroupGetMeminfo(struct virLXCMeminfo *meminfo)
 {
     g_autoptr(virCgroup) cgroup = NULL;
 
@@ -169,8 +166,6 @@ int virLXCCgroupGetMeminfo(virLXCMeminfoPtr meminfo)
 
 
 typedef struct _virLXCCgroupDevicePolicy virLXCCgroupDevicePolicy;
-typedef virLXCCgroupDevicePolicy *virLXCCgroupDevicePolicyPtr;
-
 struct _virLXCCgroupDevicePolicy {
     char type;
     int major;
@@ -179,11 +174,11 @@ struct _virLXCCgroupDevicePolicy {
 
 
 int
-virLXCSetupHostUSBDeviceCgroup(virUSBDevicePtr dev G_GNUC_UNUSED,
+virLXCSetupHostUSBDeviceCgroup(virUSBDevice *dev G_GNUC_UNUSED,
                                const char *path,
                                void *opaque)
 {
-    virCgroupPtr cgroup = opaque;
+    virCgroup *cgroup = opaque;
 
     VIR_DEBUG("Process path '%s' for USB device", path);
     if (virCgroupAllowDevicePath(cgroup, path,
@@ -195,11 +190,11 @@ virLXCSetupHostUSBDeviceCgroup(virUSBDevicePtr dev G_GNUC_UNUSED,
 
 
 int
-virLXCTeardownHostUSBDeviceCgroup(virUSBDevicePtr dev G_GNUC_UNUSED,
+virLXCTeardownHostUSBDeviceCgroup(virUSBDevice *dev G_GNUC_UNUSED,
                                   const char *path,
                                   void *opaque)
 {
-    virCgroupPtr cgroup = opaque;
+    virCgroup *cgroup = opaque;
 
     VIR_DEBUG("Process path '%s' for USB device", path);
     if (virCgroupDenyDevicePath(cgroup, path,
@@ -210,8 +205,8 @@ virLXCTeardownHostUSBDeviceCgroup(virUSBDevicePtr dev G_GNUC_UNUSED,
 }
 
 
-static int virLXCCgroupSetupDeviceACL(virDomainDefPtr def,
-                                      virCgroupPtr cgroup)
+static int virLXCCgroupSetupDeviceACL(virDomainDef *def,
+                                      virCgroup *cgroup)
 {
     int capMknod = def->caps_features[VIR_DOMAIN_PROCES_CAPS_FEATURE_MKNOD];
     size_t i;
@@ -237,7 +232,7 @@ static int virLXCCgroupSetupDeviceACL(virDomainDefPtr def,
     }
 
     for (i = 0; devices[i].type != 0; i++) {
-        virLXCCgroupDevicePolicyPtr dev = &devices[i];
+        virLXCCgroupDevicePolicy *dev = &devices[i];
         if (virCgroupAllowDevice(cgroup,
                                  dev->type,
                                  dev->major,
@@ -276,9 +271,9 @@ static int virLXCCgroupSetupDeviceACL(virDomainDefPtr def,
 
     VIR_DEBUG("Allowing any hostdev block devs");
     for (i = 0; i < def->nhostdevs; i++) {
-        virDomainHostdevDefPtr hostdev = def->hostdevs[i];
-        virDomainHostdevSubsysUSBPtr usbsrc = &hostdev->source.subsys.u.usb;
-        virUSBDevicePtr usb;
+        virDomainHostdevDef *hostdev = def->hostdevs[i];
+        virDomainHostdevSubsysUSB *usbsrc = &hostdev->source.subsys.u.usb;
+        virUSBDevice *usb;
 
         switch (hostdev->mode) {
         case VIR_DOMAIN_HOSTDEV_MODE_SUBSYS:
@@ -330,11 +325,11 @@ static int virLXCCgroupSetupDeviceACL(virDomainDefPtr def,
 
     /* Sync'ed with Host clock */
     for (i = 0; i < def->clock.ntimers; i++) {
-        virDomainTimerDefPtr timer = def->clock.timers[i];
+        virDomainTimerDef *timer = def->clock.timers[i];
         const char *dev = NULL;
 
         /* Check if "present" is set to "no" otherwise enable it. */
-        if (!timer->present)
+        if (timer->present == VIR_TRISTATE_BOOL_NO)
             continue;
 
         switch ((virDomainTimerNameType)timer->name) {
@@ -374,20 +369,20 @@ static int virLXCCgroupSetupDeviceACL(virDomainDefPtr def,
 }
 
 
-virCgroupPtr virLXCCgroupCreate(virDomainDefPtr def,
+virCgroup *virLXCCgroupCreate(virDomainDef *def,
                                 pid_t initpid,
                                 size_t nnicindexes,
                                 int *nicindexes)
 {
-    virCgroupPtr cgroup = NULL;
+    virCgroup *cgroup = NULL;
     g_autofree char *machineName = virLXCDomainGetMachineName(def, 0);
 
     if (!machineName)
         return NULL;
 
-    if (def->resource->partition[0] != '/') {
+    if (!g_path_is_absolute(def->resource->partition)) {
         virReportError(VIR_ERR_CONFIG_UNSUPPORTED,
-                       _("Resource partition '%s' must start with '/'"),
+                       _("Resource partition '%1$s' must start with '/'"),
                        def->resource->partition);
         return NULL;
     }
@@ -420,9 +415,9 @@ virCgroupPtr virLXCCgroupCreate(virDomainDefPtr def,
 }
 
 
-int virLXCCgroupSetup(virDomainDefPtr def,
-                      virCgroupPtr cgroup,
-                      virBitmapPtr nodemask)
+int virLXCCgroupSetup(virDomainDef *def,
+                      virCgroup *cgroup,
+                      virBitmap *nodemask)
 {
     if (virLXCCgroupSetupCpuTune(def, cgroup) < 0)
         return -1;
