@@ -514,8 +514,7 @@ virNWFilterDoInstantiate(virNWFilterTechDriver *techdriver,
             } else {
                 rc = -1;
                 virReportError(VIR_ERR_PARSE_FAILED,
-                               _("filter '%s' "
-                                 "learning value '%s' invalid."),
+                               _("filter '%1$s' learning value '%2$s' invalid."),
                                filter->name, learning);
                 goto error;
             }
@@ -576,8 +575,8 @@ virNWFilterDoInstantiate(virNWFilterTechDriver *techdriver,
     buf = virNWFilterPrintVars(missing_vars, ", ", false, reportIP);
     if (buf) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
-                       _("Cannot instantiate filter due to unresolvable "
-                         "variables or unavailable list elements: %s"), buf);
+                       _("Cannot instantiate filter due to unresolvable variables or unavailable list elements: %1$s"),
+                       buf);
     }
 
     rc = -1;
@@ -632,8 +631,7 @@ virNWFilterInstantiateFilterUpdate(virNWFilterDriverState *driver,
 
     if (!techdriver) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
-                       _("Could not get access to ACL tech "
-                         "driver '%s'"),
+                       _("Could not get access to ACL tech driver '%1$s'"),
                        drvname);
         return -1;
     }
@@ -779,8 +777,7 @@ virNWFilterRollbackUpdateFilter(virNWFilterBindingDef *binding)
     techdriver = virNWFilterTechDriverForName(drvname);
     if (!techdriver) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
-                       _("Could not get access to ACL tech "
-                         "driver '%s'"),
+                       _("Could not get access to ACL tech driver '%1$s'"),
                        drvname);
         return -1;
     }
@@ -805,8 +802,7 @@ virNWFilterTearOldFilter(virNWFilterBindingDef *binding)
     techdriver = virNWFilterTechDriverForName(drvname);
     if (!techdriver) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
-                       _("Could not get access to ACL tech "
-                         "driver '%s'"),
+                       _("Could not get access to ACL tech driver '%1$s'"),
                        drvname);
         return -1;
     }
@@ -830,8 +826,7 @@ _virNWFilterTeardownFilter(const char *ifname)
 
     if (!techdriver) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
-                       _("Could not get access to ACL tech "
-                         "driver '%s'"),
+                       _("Could not get access to ACL tech driver '%1$s'"),
                        drvname);
         return -1;
     }
