@@ -103,7 +103,7 @@ virNetTLSContextCheckCertFile(const char *type, const char *file, bool allowMiss
             return 1;
 
         virReportSystemError(errno,
-                             _("Cannot read %s '%s'"),
+                             _("Cannot read %1$s '%2$s'"),
                              type, file);
         return -1;
     }
@@ -134,10 +134,10 @@ static int virNetTLSContextCheckCertTimes(gnutls_x509_crt_t cert,
     if (gnutls_x509_crt_get_expiration_time(cert) < now) {
         virReportError(VIR_ERR_SYSTEM_ERROR,
                        (isCA ?
-                        _("The CA certificate %s has expired") :
+                        _("The CA certificate %1$s has expired") :
                         (isServer ?
-                         _("The server certificate %s has expired") :
-                         _("The client certificate %s has expired"))),
+                         _("The server certificate %1$s has expired") :
+                         _("The client certificate %1$s has expired"))),
                        certFile);
         return -1;
     }
@@ -145,10 +145,10 @@ static int virNetTLSContextCheckCertTimes(gnutls_x509_crt_t cert,
     if (gnutls_x509_crt_get_activation_time(cert) > now) {
         virReportError(VIR_ERR_SYSTEM_ERROR,
                        (isCA ?
-                        _("The CA certificate %s is not yet active") :
+                        _("The CA certificate %1$s is not yet active") :
                         (isServer ?
-                         _("The server certificate %s is not yet active") :
-                         _("The client certificate %s is not yet active"))),
+                         _("The server certificate %1$s is not yet active") :
+                         _("The client certificate %1$s is not yet active"))),
                        certFile);
         return -1;
     }
@@ -170,28 +170,28 @@ static int virNetTLSContextCheckCertBasicConstraints(gnutls_x509_crt_t cert,
     if (status > 0) { /* It is a CA cert */
         if (!isCA) {
             virReportError(VIR_ERR_SYSTEM_ERROR, isServer ?
-                           _("The certificate %s basic constraints show a CA, but we need one for a server") :
-                           _("The certificate %s basic constraints show a CA, but we need one for a client"),
+                           _("The certificate %1$s basic constraints show a CA, but we need one for a server") :
+                           _("The certificate %1$s basic constraints show a CA, but we need one for a client"),
                            certFile);
             return -1;
         }
     } else if (status == 0) { /* It is not a CA cert */
         if (isCA) {
             virReportError(VIR_ERR_SYSTEM_ERROR,
-                           _("The certificate %s basic constraints do not show a CA"),
+                           _("The certificate %1$s basic constraints do not show a CA"),
                            certFile);
             return -1;
         }
     } else if (status == GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE) { /* Missing basicConstraints */
         if (isCA) {
             virReportError(VIR_ERR_SYSTEM_ERROR,
-                           _("The certificate %s is missing basic constraints for a CA"),
+                           _("The certificate %1$s is missing basic constraints for a CA"),
                            certFile);
             return -1;
         }
     } else { /* General error */
         virReportError(VIR_ERR_SYSTEM_ERROR,
-                       _("Unable to query certificate %s basic constraints %s"),
+                       _("Unable to query certificate %1$s basic constraints %2$s"),
                        certFile, gnutls_strerror(status));
         return -1;
     }
@@ -217,7 +217,7 @@ static int virNetTLSContextCheckCertKeyUsage(gnutls_x509_crt_t cert,
                 GNUTLS_KEY_DIGITAL_SIGNATURE|GNUTLS_KEY_KEY_ENCIPHERMENT;
         } else {
             virReportError(VIR_ERR_SYSTEM_ERROR,
-                           _("Unable to query certificate %s key usage %s"),
+                           _("Unable to query certificate %1$s key usage %2$s"),
                            certFile, gnutls_strerror(status));
             return -1;
         }
@@ -227,7 +227,7 @@ static int virNetTLSContextCheckCertKeyUsage(gnutls_x509_crt_t cert,
         if (!(usage & GNUTLS_KEY_KEY_CERT_SIGN)) {
             if (critical) {
                 virReportError(VIR_ERR_SYSTEM_ERROR,
-                               _("Certificate %s usage does not permit certificate signing"),
+                               _("Certificate %1$s usage does not permit certificate signing"),
                                certFile);
                 return -1;
             } else {
@@ -239,7 +239,7 @@ static int virNetTLSContextCheckCertKeyUsage(gnutls_x509_crt_t cert,
         if (!(usage & GNUTLS_KEY_DIGITAL_SIGNATURE)) {
             if (critical) {
                 virReportError(VIR_ERR_SYSTEM_ERROR,
-                               _("Certificate %s usage does not permit digital signature"),
+                               _("Certificate %1$s usage does not permit digital signature"),
                                certFile);
                 return -1;
             } else {
@@ -250,7 +250,7 @@ static int virNetTLSContextCheckCertKeyUsage(gnutls_x509_crt_t cert,
         if (!(usage & GNUTLS_KEY_KEY_ENCIPHERMENT)) {
             if (critical) {
                 virReportError(VIR_ERR_SYSTEM_ERROR,
-                               _("Certificate %s usage does not permit key encipherment"),
+                               _("Certificate %1$s usage does not permit key encipherment"),
                                certFile);
                 return -1;
             } else {
@@ -291,7 +291,7 @@ static int virNetTLSContextCheckCertKeyPurpose(gnutls_x509_crt_t cert,
         }
         if (status != GNUTLS_E_SHORT_MEMORY_BUFFER) {
             virReportError(VIR_ERR_SYSTEM_ERROR,
-                           _("Unable to query certificate %s key purpose %s"),
+                           _("Unable to query certificate %1$s key purpose %2$s"),
                            certFile, gnutls_strerror(status));
             return -1;
         }
@@ -301,7 +301,7 @@ static int virNetTLSContextCheckCertKeyPurpose(gnutls_x509_crt_t cert,
         if (status < 0) {
             VIR_FREE(buffer);
             virReportError(VIR_ERR_SYSTEM_ERROR,
-                           _("Unable to query certificate %s key purpose %s"),
+                           _("Unable to query certificate %1$s key purpose %2$s"),
                            certFile, gnutls_strerror(status));
             return -1;
         }
@@ -324,7 +324,7 @@ static int virNetTLSContextCheckCertKeyPurpose(gnutls_x509_crt_t cert,
         if (!allowServer) {
             if (critical) {
                 virReportError(VIR_ERR_SYSTEM_ERROR,
-                               _("Certificate %s purpose does not allow use for with a TLS server"),
+                               _("Certificate %1$s purpose does not allow use for with a TLS server"),
                                certFile);
                 return -1;
             } else {
@@ -336,7 +336,7 @@ static int virNetTLSContextCheckCertKeyPurpose(gnutls_x509_crt_t cert,
         if (!allowClient) {
             if (critical) {
                 virReportError(VIR_ERR_SYSTEM_ERROR,
-                               _("Certificate %s purpose does not allow use for with a TLS client"),
+                               _("Certificate %1$s purpose does not allow use for with a TLS client"),
                                certFile);
                 return -1;
             } else {
@@ -389,7 +389,7 @@ virNetTLSContextCheckCertDN(gnutls_x509_crt_t cert,
     if (hostname &&
         !gnutls_x509_crt_check_hostname(cert, hostname)) {
         virReportError(VIR_ERR_RPC,
-                       _("Certificate %s owner does not match the hostname %s"),
+                       _("Certificate %1$s owner does not match the hostname %2$s"),
                        certFile, hostname);
         return -1;
     }
@@ -438,8 +438,8 @@ static int virNetTLSContextCheckCertPair(gnutls_x509_crt_t cert,
                                     NULL, 0,
                                     0, &status) < 0) {
         virReportError(VIR_ERR_SYSTEM_ERROR, isServer ?
-                       _("Unable to verify server certificate %s against CA certificate %s") :
-                       _("Unable to verify client certificate %s against CA certificate %s"),
+                       _("Unable to verify server certificate %1$s against CA certificate %2$s") :
+                       _("Unable to verify client certificate %1$s against CA certificate %2$s"),
                        certFile, cacertFile);
         return -1;
     }
@@ -460,7 +460,7 @@ static int virNetTLSContextCheckCertPair(gnutls_x509_crt_t cert,
             reason = _("The certificate uses an insecure algorithm");
 
         virReportError(VIR_ERR_SYSTEM_ERROR,
-                       _("Our own certificate %s failed validation against %s: %s"),
+                       _("Our own certificate %1$s failed validation against %2$s: %3$s"),
                        certFile, cacertFile, reason);
         return -1;
     }
@@ -494,8 +494,8 @@ static gnutls_x509_crt_t virNetTLSContextLoadCertFromFile(const char *certFile,
 
     if (gnutls_x509_crt_import(cert, &data, GNUTLS_X509_FMT_PEM) < 0) {
         virReportError(VIR_ERR_SYSTEM_ERROR, isServer ?
-                       _("Unable to import server certificate %s") :
-                       _("Unable to import client certificate %s"),
+                       _("Unable to import server certificate %1$s") :
+                       _("Unable to import client certificate %1$s"),
                        certFile);
         goto cleanup;
     }
@@ -529,7 +529,7 @@ static int virNetTLSContextLoadCACertListFromFile(const char *certFile,
 
     if (gnutls_x509_crt_list_import(certs, &certMax, &data, GNUTLS_X509_FMT_PEM, 0) < 0) {
         virReportError(VIR_ERR_SYSTEM_ERROR,
-                       _("Unable to import CA certificate list %s"),
+                       _("Unable to import CA certificate list %1$s"),
                        certFile);
         return -1;
     }
@@ -602,7 +602,7 @@ static int virNetTLSContextLoadCredentials(virNetTLSContext *ctxt,
                                                      GNUTLS_X509_FMT_PEM);
         if (err < 0) {
             virReportError(VIR_ERR_SYSTEM_ERROR,
-                           _("Unable to set x509 CA certificate: %s: %s"),
+                           _("Unable to set x509 CA certificate: %1$s: %2$s"),
                            cacert, gnutls_strerror(err));
             return -1;
         }
@@ -620,7 +620,7 @@ static int virNetTLSContextLoadCredentials(virNetTLSContext *ctxt,
                                                        GNUTLS_X509_FMT_PEM);
             if (err < 0) {
                 virReportError(VIR_ERR_SYSTEM_ERROR,
-                               _("Unable to set x509 certificate revocation list: %s: %s"),
+                               _("Unable to set x509 certificate revocation list: %1$s: %2$s"),
                                cacrl, gnutls_strerror(err));
                 return -1;
             }
@@ -645,7 +645,7 @@ static int virNetTLSContextLoadCredentials(virNetTLSContext *ctxt,
                                                      GNUTLS_X509_FMT_PEM);
             if (err < 0) {
                 virReportError(VIR_ERR_SYSTEM_ERROR,
-                               _("Unable to set x509 key and certificate: %s, %s: %s"),
+                               _("Unable to set x509 key and certificate: %1$s, %2$s: %3$s"),
                                key, cert, gnutls_strerror(err));
                 return -1;
             }
@@ -690,7 +690,7 @@ static virNetTLSContext *virNetTLSContextNew(const char *cacert,
         ctxt->x509cred = NULL;
 
         virReportError(VIR_ERR_SYSTEM_ERROR,
-                       _("Unable to allocate x509 credentials: %s"),
+                       _("Unable to allocate x509 credentials: %1$s"),
                        gnutls_strerror(err));
         goto error;
     }
@@ -896,7 +896,7 @@ int virNetTLSContextReloadForServer(virNetTLSContext *ctxt,
     err = gnutls_certificate_allocate_credentials(&ctxt->x509cred);
     if (err) {
         virReportError(VIR_ERR_SYSTEM_ERROR,
-                       _("Unable to allocate x509 credentials: %s"),
+                       _("Unable to allocate x509 credentials: %1$s"),
                        gnutls_strerror(err));
         goto error;
     }
@@ -946,7 +946,7 @@ static int virNetTLSContextValidCertificate(virNetTLSContext *ctxt,
 
     if ((ret = gnutls_certificate_verify_peers2(sess->session, &status)) < 0) {
         virReportError(VIR_ERR_SYSTEM_ERROR,
-                       _("Unable to verify TLS peer: %s"),
+                       _("Unable to verify TLS peer: %1$s"),
                        gnutls_strerror(ret));
         goto authdeny;
     }
@@ -967,7 +967,7 @@ static int virNetTLSContextValidCertificate(virNetTLSContext *ctxt,
             reason = _("The certificate uses an insecure algorithm");
 
         virReportError(VIR_ERR_SYSTEM_ERROR,
-                       _("Certificate failed validation: %s"),
+                       _("Certificate failed validation: %1$s"),
                        reason);
         goto authdeny;
     }
@@ -1016,7 +1016,7 @@ static int virNetTLSContextValidCertificate(virNetTLSContext *ctxt,
             }
             if (ret != 0) {
                 virReportError(VIR_ERR_SYSTEM_ERROR,
-                               _("Failed to get certificate %s distinguished name: %s"),
+                               _("Failed to get certificate %1$s distinguished name: %2$s"),
                                "[session]", gnutls_strerror(ret));
                 goto authfail;
             }
@@ -1160,7 +1160,7 @@ virNetTLSSession *virNetTLSSessionNew(virNetTLSContext *ctxt,
     if ((err = gnutls_init(&sess->session,
                            ctxt->isServer ? GNUTLS_SERVER : GNUTLS_CLIENT)) != 0) {
         virReportError(VIR_ERR_SYSTEM_ERROR,
-                       _("Failed to initialize TLS session: %s"),
+                       _("Failed to initialize TLS session: %1$s"),
                        gnutls_strerror(err));
         goto error;
     }
@@ -1174,7 +1174,7 @@ virNetTLSSession *virNetTLSSessionNew(virNetTLSContext *ctxt,
                                           priority,
                                           NULL)) != 0) {
         virReportError(VIR_ERR_SYSTEM_ERROR,
-                       _("Failed to set TLS session priority to %s: %s"),
+                       _("Failed to set TLS session priority to %1$s: %2$s"),
                        priority, gnutls_strerror(err));
         goto error;
     }
@@ -1183,7 +1183,7 @@ virNetTLSSession *virNetTLSSessionNew(virNetTLSContext *ctxt,
                                       GNUTLS_CRD_CERTIFICATE,
                                       ctxt->x509cred)) != 0) {
         virReportError(VIR_ERR_SYSTEM_ERROR,
-                       _("Failed set TLS x509 credentials: %s"),
+                       _("Failed set TLS x509 credentials: %1$s"),
                        gnutls_strerror(err));
         goto error;
     }
@@ -1313,7 +1313,7 @@ int virNetTLSSessionHandshake(virNetTLSSession *sess)
 #endif
 
     virReportError(VIR_ERR_AUTH_FAILED,
-                   _("TLS handshake failed %s"),
+                   _("TLS handshake failed %1$s"),
                    gnutls_strerror(ret));
     ret = -1;
 
