@@ -82,7 +82,7 @@ virDevMapperGetMajor(unsigned int *major)
 
     if (!lines[i]) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
-                       _("Unable to find major for %s"),
+                       _("Unable to find major for %1$s"),
                        DM_NAME);
         return -1;
     }
@@ -154,7 +154,7 @@ virDMOpen(void)
 
     if (dm.version[0] != DM_VERSION_MAJOR) {
         virReportError(VIR_ERR_OPERATION_UNSUPPORTED,
-                       _("Unsupported device-mapper version. Expected %d got %d"),
+                       _("Unsupported device-mapper version. Expected %1$d got %2$d"),
                        DM_VERSION_MAJOR, dm.version[0]);
         return -1;
     }
@@ -185,7 +185,7 @@ virDMSanitizepath(const char *path)
     /* It's a path. Check if the last component is DM name */
     if (stat(path, &sb[0]) < 0) {
         virReportError(errno,
-                       _("Unable to stat %p"),
+                       _("Unable to stat %1$p"),
                        path);
         return NULL;
     }
@@ -252,7 +252,7 @@ virDevMapperGetTargetsImpl(int controlFD,
             return 0;
 
         virReportSystemError(errno,
-                             _("Unable to query dependencies for %s"),
+                             _("Unable to query dependencies for %1$s"),
                              path);
         return -1;
     }
