@@ -441,7 +441,7 @@ qemuMonitorTestFree(qemuMonitorTest *test)
 }
 
 
-int
+void
 qemuMonitorTestAddHandler(qemuMonitorTest *test,
                           const char *identifier,
                           qemuMonitorTestResponseCallback cb,
@@ -460,8 +460,6 @@ qemuMonitorTestAddHandler(qemuMonitorTest *test,
     VIR_WITH_MUTEX_LOCK_GUARD(&test->lock) {
         VIR_APPEND_ELEMENT(test->items, test->nitems, item);
     }
-
-    return 0;
 }
 
 void *
@@ -471,19 +469,10 @@ qemuMonitorTestItemGetPrivateData(qemuMonitorTestItem *item)
 }
 
 
-typedef struct _qemuMonitorTestCommandArgs qemuMonitorTestCommandArgs;
-struct _qemuMonitorTestCommandArgs {
-    char *argname;
-    char *argval;
-};
-
-
 struct qemuMonitorTestHandlerData {
     char *command_name;
     char *cmderr;
     char *response;
-    size_t nargs;
-    qemuMonitorTestCommandArgs *args;
     char *expectArgs;
 };
 
@@ -491,20 +480,13 @@ static void
 qemuMonitorTestHandlerDataFree(void *opaque)
 {
     struct qemuMonitorTestHandlerData *data = opaque;
-    size_t i;
 
     if (!data)
         return;
 
-    for (i = 0; i < data->nargs; i++) {
-        g_free(data->args[i].argname);
-        g_free(data->args[i].argval);
-    }
-
     g_free(data->command_name);
     g_free(data->cmderr);
     g_free(data->response);
-    g_free(data->args);
     g_free(data->expectArgs);
     g_free(data);
 }
@@ -604,10 +586,12 @@ qemuMonitorTestAddItem(qemuMonitorTest *test,
     data->command_name = g_strdup(command_name);
     data->response = g_strdup(response);
 
-    return qemuMonitorTestAddHandler(test,
-                                     command_name,
-                                     qemuMonitorTestProcessCommandDefault,
-                                     data, qemuMonitorTestHandlerDataFree);
+    qemuMonitorTestAddHandler(test,
+                              command_name,
+                              qemuMonitorTestProcessCommandDefault,
+                              data, qemuMonitorTestHandlerDataFree);
+
+    return 0;
 }
 
 
@@ -673,24 +657,23 @@ qemuMonitorTestAddItemVerbatim(qemuMonitorTest *test,
                                const char *response)
 {
     struct qemuMonitorTestHandlerData *data;
+    char *reformatted = NULL;
+
+    if (!(reformatted = virJSONStringReformat(command, false)))
+        return -1;
 
     data = g_new0(struct qemuMonitorTestHandlerData, 1);
 
     data->response = g_strdup(response);
     data->cmderr = g_strdup(cmderr);
+    data->command_name = g_steal_pointer(&reformatted);
 
-    data->command_name = virJSONStringReformat(command, false);
-    if (!data->command_name)
-        goto error;
+    qemuMonitorTestAddHandler(test,
+                              command,
+                              qemuMonitorTestProcessCommandVerbatim,
+                              data, qemuMonitorTestHandlerDataFree);
 
-    return qemuMonitorTestAddHandler(test,
-                                     command,
-                                     qemuMonitorTestProcessCommandVerbatim,
-                                     data, qemuMonitorTestHandlerDataFree);
-
- error:
-    qemuMonitorTestHandlerDataFree(data);
-    return -1;
+    return 0;
 }
 
 
@@ -735,217 +718,12 @@ qemuMonitorTestAddAgentSyncResponse(qemuMonitorTest *test)
         return -1;
     }
 
-    return qemuMonitorTestAddHandler(test,
-                                     "agent-sync",
-                                     qemuMonitorTestProcessGuestAgentSync,
-                                     NULL, NULL);
-}
+    qemuMonitorTestAddHandler(test,
+                              "agent-sync",
+                              qemuMonitorTestProcessGuestAgentSync,
+                              NULL, NULL);
 
-
-static int
-qemuMonitorTestProcessCommandWithArgs(qemuMonitorTest *test,
-                                      qemuMonitorTestItem *item,
-                                      const char *cmdstr)
-{
-    struct qemuMonitorTestHandlerData *data = item->opaque;
-    g_autoptr(virJSONValue) val = NULL;
-    virJSONValue *args;
-    virJSONValue *argobj;
-    const char *cmdname;
-    size_t i;
-
-    if (!(val = virJSONValueFromString(cmdstr)))
-        return -1;
-
-    if (!(cmdname = virJSONValueObjectGetString(val, "execute"))) {
-        qemuMonitorTestError("Missing command name in %s", cmdstr);
-        return -1;
-    }
-
-    if (data->command_name &&
-        STRNEQ(data->command_name, cmdname)) {
-        qemuMonitorTestErrorInvalidCommand(data->command_name, cmdname);
-        return -1;
-    }
-
-    if (!(args = virJSONValueObjectGet(val, "arguments"))) {
-        qemuMonitorTestError("Missing arguments section for command '%s'",
-                             NULLSTR(data->command_name));
-        return -1;
-    }
-
-    /* validate the args */
-    for (i = 0; i < data->nargs; i++) {
-        qemuMonitorTestCommandArgs *arg = &data->args[i];
-        g_autofree char *argstr = NULL;
-
-        if (!(argobj = virJSONValueObjectGet(args, arg->argname))) {
-            qemuMonitorTestError("Missing argument '%s' for command '%s'",
-                                 arg->argname,
-                                 NULLSTR(data->command_name));
-            return -1;
-        }
-
-        /* convert the argument to string */
-        if (!(argstr = virJSONValueToString(argobj, false)))
-            return -1;
-
-        /* verify that the argument value is expected */
-        if (STRNEQ(argstr, arg->argval)) {
-            qemuMonitorTestError("Invalid value of argument '%s' of command '%s': "
-                                 "expected '%s' got '%s'",
-                                 arg->argname,
-                                 NULLSTR(data->command_name),
-                                 arg->argval, argstr);
-            return -1;
-        }
-    }
-
-    /* arguments checked out, return the response */
-    return qemuMonitorTestAddResponse(test, data->response);
-}
-
-
-
-/* this allows to add a responder that is able to check
- * a (shallow) structure of arguments for a command */
-int
-qemuMonitorTestAddItemParams(qemuMonitorTest *test,
-                             const char *cmdname,
-                             const char *response,
-                             ...)
-{
-    struct qemuMonitorTestHandlerData *data;
-    const char *argname;
-    const char *argval;
-    va_list args;
-
-    va_start(args, response);
-
-    data = g_new0(struct qemuMonitorTestHandlerData, 1);
-
-    data->command_name = g_strdup(cmdname);
-    data->response = g_strdup(response);
-
-    while ((argname = va_arg(args, char *))) {
-        size_t i;
-        if (!(argval = va_arg(args, char *))) {
-            virReportError(VIR_ERR_INTERNAL_ERROR,
-                           "Missing argument value for argument '%s'",
-                           argname);
-            goto error;
-        }
-
-        i = data->nargs;
-        VIR_EXPAND_N(data->args, data->nargs, 1);
-        data->args[i].argname = g_strdup(argname);
-        data->args[i].argval = g_strdup(argval);
-    }
-
-    va_end(args);
-
-    return qemuMonitorTestAddHandler(test,
-                                     cmdname,
-                                     qemuMonitorTestProcessCommandWithArgs,
-                                     data, qemuMonitorTestHandlerDataFree);
-
- error:
-    va_end(args);
-    qemuMonitorTestHandlerDataFree(data);
-    return -1;
-}
-
-
-static int
-qemuMonitorTestProcessCommandWithArgStr(qemuMonitorTest *test,
-                                        qemuMonitorTestItem *item,
-                                        const char *cmdstr)
-{
-    struct qemuMonitorTestHandlerData *data = item->opaque;
-    g_autoptr(virJSONValue) val = NULL;
-    virJSONValue *args;
-    g_autofree char *argstr = NULL;
-    const char *cmdname;
-
-    if (!(val = virJSONValueFromString(cmdstr)))
-        return -1;
-
-    if (!(cmdname = virJSONValueObjectGetString(val, "execute"))) {
-        qemuMonitorTestError("Missing command name in %s", cmdstr);
-        return -1;
-    }
-
-    if (STRNEQ(data->command_name, cmdname)) {
-        qemuMonitorTestErrorInvalidCommand(data->command_name, cmdname);
-        return -1;
-    }
-
-    if (!(args = virJSONValueObjectGet(val, "arguments"))) {
-        qemuMonitorTestError("Missing arguments section for command '%s'",
-                             data->command_name);
-        return -1;
-    }
-
-    /* convert the arguments to string */
-    if (!(argstr = virJSONValueToString(args, false)))
-        return -1;
-
-    /* verify that the argument value is expected */
-    if (STRNEQ(argstr, data->expectArgs)) {
-        qemuMonitorTestError("%s: expected arguments: '%s', got: '%s'",
-                             data->command_name,
-                             data->expectArgs, argstr);
-        return -1;
-    }
-
-    /* arguments checked out, return the response */
-    return qemuMonitorTestAddResponse(test, data->response);
-}
-
-
-/**
- * qemuMonitorTestAddItemExpect:
- *
- * @test: test monitor object
- * @cmdname: command name
- * @cmdargs: expected arguments of the command
- * @apostrophe: convert apostrophes (') in @cmdargs to quotes (")
- * @response: simulated response of the command
- *
- * Simulates a qemu monitor command. Checks that the 'arguments' of the qmp
- * command are expected. If @apostrophe is true apostrophes are converted to
- * quotes for simplification of writing the strings into code.
- */
-int
-qemuMonitorTestAddItemExpect(qemuMonitorTest *test,
-                             const char *cmdname,
-                             const char *cmdargs,
-                             bool apostrophe,
-                             const char *response)
-{
-    struct qemuMonitorTestHandlerData *data;
-
-    data = g_new0(struct qemuMonitorTestHandlerData, 1);
-
-    data->command_name = g_strdup(cmdname);
-    data->response = g_strdup(response);
-    data->expectArgs = g_strdup(cmdargs);
-
-    if (apostrophe) {
-        char *tmp = data->expectArgs;
-
-        while (*tmp != '\0') {
-            if (*tmp == '\'')
-                *tmp = '"';
-
-            tmp++;
-        }
-    }
-
-    return qemuMonitorTestAddHandler(test,
-                                     cmdname,
-                                     qemuMonitorTestProcessCommandWithArgStr,
-                                     data, qemuMonitorTestHandlerDataFree);
+    return 0;
 }
 
 
